@@ -4,4 +4,4 @@
 #' 
 #' @docType package
 #' @name tidyUSDA
-NULL
\ No newline at end of file
+"_PACKAGE"
\ No newline at end of file
